Project of CSE 3200: System Development Laboratory by:

Ashikur Rahman (Roll: 1707090)
Samin Yeasar (Roll: 1507099)
CSE, KUET

Supervised by:

Dr. Sk. Mohammad Masudul Ahsan

Professor

Department of Computer Science & Engineering

Khulna University of Engineering & Technology (KUET)